#!/bin/bash

# release locations
GLOBAL_RELEASE_DIR=/common/usr/cscofe/silecs

function help {
    echo -e ""
    echo -e "Script in order to build and install the complete silecs framework"
    echo -e ""
    echo -e "Usage:"
    echo -e ""
    echo -e "\t Install version 1.2.3 to default directory ($GLOBAL_RELEASE_DIR):"
    echo -e "\t\t ./build_and_install.sh 1.2.3"
    echo -e ""
    echo -e "\t Install version 1.2.3 to custom directory:"
    echo -e "\t\t ./build_and_install.sh 1.2.3 /home/user/MyCustomDir"
    echo -e ""
    exit 1;
}

if [ $# -lt 1 ]
  then
    echo "Error: Wrong number of arguments supplied."
    help
fi

if [[ "$1" == "-h" || "$1" == "--help" ]];
then
    help
fi

# Build and install instructions for modbus library:
# ./configure --prefix=/common/usr/cscofe/silecs/modbus/3.1.7 --enable-static
# make -j4
# make install

# List of silecs packages which can be released
PACKAGES="silecs-codegen silecs-model modbus snap7 silecs-communication-cpp silecs-diagnostic-cpp silecs_cli silecs-cli-client"

SCRIPT=$(readlink -f "$0")
SCRIPTPATH=$(dirname "$SCRIPT")     # path where this script is located in

SILECS_VERSION_FULL=$1
SILECS_VERSION_MAJOR=`echo ${SILECS_VERSION_FULL} | cut -d. -f1`
SILECS_VERSION_MINOR=`echo ${SILECS_VERSION_FULL} | cut -d. -f2`

if [ -z "$2" ]
  then
    RELEASE_DIR_BASE=$GLOBAL_RELEASE_DIR
  else
    RELEASE_DIR_BASE=$2
fi



for PACKAGE in $PACKAGES; do
    echo "installing package ${PACKAGE} into ${RELEASE_DIR_BASE}"
    mkdir -p ${RELEASE_DIR_BASE}
    ${PACKAGE}/install.sh ${RELEASE_DIR_BASE} ${SILECS_VERSION_FULL}
    if [ "$?" -eq "1" ]; then
        echo "Error: Package ${PACKAGE} skipped"
    fi
done

# Create silecs environment file to be easily sourced for users
echo -e "Create silecs environment file"
SILECS_ENV_FILE=${RELEASE_DIR_BASE}/${SILECS_VERSION_FULL}/silecs_environment
echo $SILECS_ENV_FILE
touch $SILECS_ENV_FILE
echo -e "SILECS_VERSION=${SILECS_VERSION_FULL}" >> $SILECS_ENV_FILE; 
echo -e "export PATH=${RELEASE_DIR_BASE}/\$SILECS_VERSION/silecs-cli:\${PATH}" >> $SILECS_ENV_FILE;
echo -e "export PATH=${RELEASE_DIR_BASE}/\$SILECS_VERSION/silecs-cli-client/bin/x86_64:\${PATH}" >> $SILECS_ENV_FILE;
echo -e "export PATH=${RELEASE_DIR_BASE}/\$SILECS_VERSION/silecs-diagnostic-cpp/bin/x86_64:\${PATH}" >> $SILECS_ENV_FILE;

# Update links to latest versions
echo -e "Update links to silecs versions"

# Update link to latest version
LATEST_LINK=${RELEASE_DIR_BASE}/latest
if [ -L ${LATEST_LINK} ]; then
    rm ${LATEST_LINK}
fi
ln -fvs ${RELEASE_DIR_BASE}/${SILECS_VERSION_FULL} ${LATEST_LINK}

# Update link to major.minor version
MAJOR_MINOR_LINK=${RELEASE_DIR_BASE}/${SILECS_VERSION_MAJOR}.${SILECS_VERSION_MINOR}
if [ -L ${MAJOR_MINOR_LINK} ]; then
    rm ${MAJOR_MINOR_LINK}
fi
ln -fvs ${RELEASE_DIR_BASE}/${SILECS_VERSION_FULL} ${MAJOR_MINOR_LINK}

# Update link to major version
MAJOR_LINK=${RELEASE_DIR_BASE}/${SILECS_VERSION_MAJOR}
if [ -L ${MAJOR_LINK} ]; then
    rm ${MAJOR_LINK}
fi
ln -fvs ${RELEASE_DIR_BASE}/${SILECS_VERSION_FULL} ${MAJOR_LINK}

exit 0
