#!/bin/sh
set -e

# First argument has to be the desired modbus version
MODBUS_VERSION=$1

# Second argument is the install location
RELEASE_DIR=$2

SCRIPT=$(readlink -f "$0")
SCRIPTPATH=$(dirname "$SCRIPT")     # path where this script is located in
MODBUS_FOLDER=libmodbus-${MODBUS_VERSION}
MODBUS_PATH=${SCRIPTPATH}/${MODBUS_FOLDER}

echo ${MODBUS_PATH}
# If there is no modbus folder yet, we download the required version and build it
if [ -d ${MODBUS_PATH} ]; then
  echo "Some modbus version is already available. No need to download/build it"
  #TODO Check if the version matches
else
  
  archiveFile=${MODBUS_FOLDER}.tar.gz
  archiveFilePath=${SCRIPTPATH}/${archiveFile}

  if [ ! -f "$archiveFilePath" ]
  then
     echo "Downloading modbus"
     cd ${SCRIPTPATH}
     wget https://github.com/stephane/libmodbus/releases/download/v${MODBUS_VERSION}/libmodbus-${MODBUS_VERSION}.tar.gz  
  fi

  if [ ! -d ${MODBUS_PATH} ]
  then
     echo "Extracting modbus"
     tar -vxzf ${archiveFilePath}
     rm ${archiveFilePath}
  fi

  echo "Building and installing modbus"
  
  cd ${MODBUS_FOLDER}
  ./configure --enable-static --prefix=${RELEASE_DIR}
  make 
  make install
fi


