#!/bin/sh
set -e

RELEASE_DIR_BASE=$1
SILECS_VERSION=$2

MODBUS_VERSION_FULL=3.1.10
MODBUS_VERSION_MAJOR=`echo ${MODBUS_VERSION_FULL} | cut -d. -f1`
MODBUS_VERSION_MINOR=`echo ${MODBUS_VERSION_FULL} | cut -d. -f2`

SCRIPT=$(readlink -f "$0")
SCRIPTPATH=$(dirname "$SCRIPT")     # path where this script is located in

RELEASE_DIR=${RELEASE_DIR_BASE}/modbus/${MODBUS_VERSION_FULL}
if [ -d ${RELEASE_DIR} ]; then 
    echo "Error: ${RELEASE_DIR} already exists ...skipping"
    exit 1
fi

# Download and build modbus if required
${SCRIPTPATH}/build.sh ${MODBUS_VERSION_FULL} ${RELEASE_DIR}

# Make sure everybody can read all installed files
chmod a+r -R ${RELEASE_DIR}
chmod a+x -R ${RELEASE_DIR}

# Make all files write-protected to prevent overwriting an old version by accident
chmod a-w -R ${RELEASE_DIR}
    
# Update link to latest version
LATEST_LINK=${RELEASE_DIR_BASE}/modbus/latest
if [ -L ${LATEST_LINK} ]; then
    rm ${LATEST_LINK}
fi
ln -fvs ${RELEASE_DIR_BASE}/modbus/${MODBUS_VERSION_FULL} ${LATEST_LINK}

# Update links to major version
MAJOR_LINK=${RELEASE_DIR_BASE}/modbus/${MODBUS_VERSION_MAJOR}
if [ -L ${MAJOR_LINK} ]; then
    rm ${MAJOR_LINK}
fi
ln -fvs ${RELEASE_DIR_BASE}/modbus/${MODBUS_VERSION_FULL} ${MAJOR_LINK}

# Update links to major.minor version
MAJOR_MINOR_LINK=${RELEASE_DIR_BASE}/modbus/${MODBUS_VERSION_MAJOR}.${MODBUS_VERSION_MINOR}
if [ -L ${MAJOR_MINOR_LINK} ]; then
    rm ${MAJOR_MINOR_LINK}
fi
ln -fvs ${RELEASE_DIR_BASE}/modbus/${MODBUS_VERSION_FULL} ${MAJOR_MINOR_LINK}



