#!/bin/sh
set -e

# First argument has to be the desired snap7 version
SNAP7_VERSION=$1

SCRIPT=$(readlink -f "$0")
SCRIPTPATH=$(dirname "$SCRIPT")     # path where this script is located in
SNAP7_FOLDER=snap7-full-${SNAP7_VERSION}
SNAP7_PATH=${SCRIPTPATH}/${SNAP7_FOLDER}

echo ${SNAP7_PATH}
# If there is no snap7 folder yet, we download the required version and build it
if [ -d ${SNAP7_PATH} ]; then
  echo "Some snap7 version is already available. No need to download/build it"
  #TODO Check if the version matches
else
  
  archiveFile=${SNAP7_FOLDER}.tar.gz
  archiveFilePath=${SCRIPTPATH}/${SNAP7_FOLDER}.tar.gz

  echo "Cleanup"
  rm -rf snap7-ful*

  if [ ! -f "$archiveFilePath" ]
  then
     echo "Downloading snap7"
     cd ${SCRIPTPATH}
     wget http://downloads.sourceforge.net/project/snap7/${SNAP7_VERSION}/${archiveFile}
  fi

  if [ ! -d ${SNAP7_PATH} ]
  then
     echo "Extracting snap7"
     tar -vxzf ${archiveFilePath}
     rm ${archiveFilePath}
  fi

  if [ ! -d ${SCRIPTPATH}/snap7-full ]
  then
     echo "Creating symlink"
     ln -s ${SNAP7_PATH} ${SCRIPTPATH}/snap7-full
  fi

  echo "Building snap7"
  cd ${SNAP7_FOLDER}/build/unix
  make -f x86_64_linux.mk
fi


